@@ -13,9 +13,9 @@
 #'
 #'
 #' @param source source to select from.
-#' @param orderby order by column names.
+#' @param cols order by column names.
 #' @param ... force later arguments to be bound by name
-#' @param desc logical if TRUE reverse order
+#' @param rev_cols order by reverse of these column names.
 #' @param limit number limit row count.
 #' @return select columns node.
 #'
@@ -24,7 +24,7 @@
 #' my_db <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
 #' d <- dbi_copy_to(my_db, 'd',
 #'                 data.frame(AUC = 0.6, R2 = 0.2))
-#' eqn <- orderby(d, "AUC", desc=TRUE, limit=4)
+#' eqn <- orderby(d, rev_cols = "AUC", limit=4)
 #' cat(format(eqn))
 #' sql <- to_sql(eqn, my_db)
 #' cat(sql)
@@ -34,9 +34,9 @@
 #' @export
 #'
 orderby <- function(source,
-                     orderby,
+                     cols = NULL,
                      ...,
-                     desc = FALSE,
+                     rev_cols = NULL,
                      limit = NULL) {
   if(length(list(...))>0) {
     stop("unexpected arguemnts")
@@ -46,18 +46,18 @@ orderby <- function(source,
     dnode <- table_source(tmp_name, colnames(source))
     dnode$data <- source
     enode <- orderby(dnode,
-                     orderby,
-                     desc = desc,
+                     orderby = cols,
+                     rev_orderby = rev_cols,
                      limit = limit)
     return(enode)
   }
   have <- column_names(source)
-  check_have_cols(have, orderby, "rquery::orderby orderby")
+  check_have_cols(have, c(cols, rev_cols), "rquery::orderby orderterms")
   r <- list(source = list(source),
             table_name = NULL,
             parsed = NULL,
-            orderby = orderby,
-            desc = desc,
+            orderby = cols,
+            rev_orderby = rev_cols,
             limit = limit)
   r <- relop_decorate("relop_orderby", r)
   r
@@ -70,13 +70,16 @@ format.relop_orderby <- function(x, ...) {
   if(length(list(...))>0) {
     stop("unexpected arguemnts")
   }
+  ot <- c(x$orderby)
+  if(length(x$rev_orderby)>0) {
+    ot <- c(ot, paste0("desc(", x$rev_orderby, ")"))
+  }
   paste0(trimws(format(x$source[[1]]), which="right"),
          " %.>%\n ",
          "orderby(., ",
-         ifelse(length(x$orderby)>0,
-                paste(x$orderby, collapse = ", "),
+         ifelse(ot>0,
+                paste(ot, collapse = ", "),
                 ""),
-         ifelse(x$desc, ", DESC", ""),
          ifelse((length(x$limit)>0) && (length(x$orderby)>0),
                 paste0(", LIMIT ", x$limit),
                 ""),
@@ -136,6 +139,13 @@ to_sql.relop_orderby <- function (x,
                function(ci) {
                  quote_identifier(db, ci)
                }, character(1))
+  if(length(x$rev_orderby)>0) {
+    rev_ot <- vapply(x$rev_orderby,
+                     function(ci) {
+                       paste(quote_identifier(db, ci), "DESC")
+                     }, character(1))
+    ot <- c(ot, rev_ot)
+  }
   subcols <- calc_used_relop_orderby(x, using=using)
   subsql <- to_sql(x$source[[1]],
                    db = db,
@@ -153,7 +163,6 @@ to_sql.relop_orderby <- function (x,
          ifelse(length(ot)>0,
                 paste0(" ORDER BY ", paste(ot, collapse = ", ")),
                 ""),
-         ifelse((x$desc) && (length(ot)>0), " DESC", ""),
          ifelse(length(x$limit)>0,
                 paste0(" LIMIT ", x$limit),
                 ""))
